==> zbxe.beta.0.2.7.tgz: zbxe/modules/importer/lang/ru.lang.php <==
<?php
  /**
     * @file   ru.lang.php
     * @author zero <zero@nzeo.com> | translation by Maslennikov Evgeny aka X-[Vr]bL1s5 | e-mail: x-bliss[a]tut.by; ICQ: 225035467;
     * @brief  Russian basic language pack for Zeroboard XE
     **/

    // слова для кнопок
    $lang->cmd_sync_member = 'Синхронизировать';
    $lang->cmd_continue = 'Продолжить';

    // объекты
    $lang->importer = 'Импортировать данные zeroboard';
    $lang->source_type = 'Предыдущее назначение';
    $lang->type_member = 'Данные пользователей';
    $lang->type_module = 'Данные статей';
    $lang->type_syncmember = 'Синхронизировать данные пользователей';
    $lang->target_module = 'Модуль назначения';
    $lang->xml_file = 'XML файл';

    $lang->import_step_title = array(
        1 => 'Шаг 1. Выберите предыдущее назначение',
        12 => 'Шаг 1-2. Выберите модуль назначения',
        13 => 'Шаг 1-3. Выберите категорию назначения',
        2 => 'Шаг 2. Загрузить XML файл',
        3 => 'Шаг 2. Синхронизировать данные пользователей и статей',
    );

    $lang->import_step_desc = array(
        1 => 'Пожалуйста, выберите тип XML файла, который Вы хотите импортировать.',
        12 => 'Пожалуйста, выберите модуль, в который Вы хотите импортировать данные.',
        13 => 'Пожалуйста, выберите категорию назначения, в которую Вы хотите импортировать данные.',
        2 => "Пожайлуста, введите расположение XML файла, который Вы хотите импортировать.\nЕсли он находится в одном аккаунте, то введите абсолютный/относительный путь. Если нет, то введите URL, начинающийся с http://...",
        3 => 'Данные пользователей и статей могут быть некорректны после импорта. В таком случае, выполните синхронизацию для восстановления, основанного на user_id.',
    );

    // гид/алерт
    $lang->msg_sync_member = 'Синхронизация данных пользователей и статей начнется по нажатию книпоки "Синхронизировать".';
    $lang->msg_no_xml_file = 'XML файл не найден. Пожалуйста, проверьте путь еще раз';
    $lang->msg_invalid_xml_file = 'Неверный тип XML файла.';
    $lang->msg_importing = 'Пишем %d данные %d. (Если процесс "завис", нажмите кнопку "Продолжить")';
    $lang->msg_import_finished = '%d данные были поностью импортированы. В зависимости от ситуации, некоторые данные могут не быть импортированы.';
    $lang->msg_sync_completed = 'Выполнена синхронизация пользователей, статей и комментариев.';

    // blah blah.. чепуха)
    $lang->about_type_member = 'Если Вы импортируете информацию пользователей, выберите эту опцию';
    $lang->about_type_module = 'Если Вы импортируете информацию форума или статей, выберите эту опцию';
    $lang->about_type_syncmember = 'Если Вы пытаетесь синхронизировать информацию пользователей после импорта информации пользователей и статей, выберите эту опцию';
    $lang->about_importer = "Вы можете импортировать данные Zeroboard4, Zeroboard5 Beta или других программ в ZeroboardXE.\nЧтобы импортировать, Вам следует использовать <a href=\"#\" onclick=\"winopen('');return false;\">XML Экспортер (XML Exporter)</a>, чтобы конвертировать нужные данные в XML Файл и затем загрузить его.";

    $lang->about_target_path = "Чтобы получить вложения с Zeroboard4, пожалуйста, введите адрес, где установлена  Zeroboard4.\nЕсли она раположена на том же сервере, введите путь к Zeroboard4 как /home/USERID/public_html/bbs\nЕсли нет, введите адрес, где Zeroboard4 установлена. Например: http://Domain/bbs";
?>

==> zbxe.beta.0.2.8.tgz: zbxe/modules/importer/lang/ru.lang.php <==
<?php
  /**
     * @file   ru.lang.php
     * @author zero <zero@nzeo.com> | translation by Maslennikov Evgeny aka X-[Vr]bL1s5 | e-mail: x-bliss[a]tut.by; ICQ: 225035467;
     * @brief  Russian basic language pack for Zeroboard XE
     **/

    // слова для кнопок
    $lang->cmd_sync_member = 'Синхронизировать';
    $lang->cmd_continue = 'Продолжить';

    // объекты
    $lang->importer = 'Импортировать данные zeroboard';
    $lang->source_type = 'Предыдущее назначение';
    $lang->type_member = 'Данные пользователей';
    $lang->type_message = '쪽지(메세지) 정보';
    $lang->type_ttxml = 'TTXML';
    $lang->type_module = 'Данные статей';
    $lang->type_syncmember = 'Синхронизировать данные пользователей';
    $lang->target_module = 'Модуль назначения';
    $lang->xml_file = 'XML файл';

    $lang->import_step_title = array(
        1 => 'Шаг 1. Выберите предыдущее назначение',
        12 => 'Шаг 1-2. Выберите модуль назначения',
        13 => 'Шаг 1-3. Выберите категорию назначения',
        2 => 'Шаг 2. Загрузить XML файл',
        3 => 'Шаг 2. Синхронизировать данные пользователей и статей',
    );

    $lang->import_step_desc = array(
        1 => 'Пожалуйста, выберите тип XML файла, который Вы хотите импортировать.',
        12 => 'Пожалуйста, выберите модуль, в который Вы хотите импортировать данные.',
        13 => 'Пожалуйста, выберите категорию назначения, в которую Вы хотите импортировать данные.',
        2 => "Пожайлуста, введите расположение XML файла, который Вы хотите импортировать.\nЕсли он находится в одном аккаунте, то введите абсолютный/относительный путь. Если нет, то введите URL, начинающийся с http://...",
        3 => 'Данные пользователей и статей могут быть некорректны после импорта. В таком случае, выполните синхронизацию для восстановления, основанного на user_id.',
    );

    // гид/алерт
    $lang->msg_sync_member = 'Синхронизация данных пользователей и статей начнется по нажатию книпоки "Синхронизировать".';
    $lang->msg_no_xml_file = 'XML файл не найден. Пожалуйста, проверьте путь еще раз';
    $lang->msg_invalid_xml_file = 'Неверный тип XML файла.';
    $lang->msg_importing = 'Пишем %d данные %d. (Если процесс "завис", нажмите кнопку "Продолжить")';
    $lang->msg_import_finished = '%d/%d данные были поностью импортированы. В зависимости от ситуации, некоторые данные могут не быть импортированы.';
    $lang->msg_sync_completed = 'Выполнена синхронизация пользователей, статей и комментариев.';

    // blah blah.. чепуха)
    $lang->about_type_member = 'Если Вы импортируете информацию пользователей, выберите эту опцию';
    $lang->about_type_message = '데이터 이전 대상이 쪽지(메세지)일 경우 선택해주세요';
    $lang->about_type_ttxml = '데이터 이전 대상이 TTXML(textcube계열)일 경우 선택해주세요';
    $lang->about_ttxml_user_id = 'TTXML이전시에 글쓴이로 지정할 사용자 아이디를 입력해주세요. (이미 가입된 아이디여야 합니다)';
    $lang->about_type_module = 'Если Вы импортируете информацию форума или статей, выберите эту опцию';
    $lang->about_type_syncmember = 'Если Вы пытаетесь синхронизировать информацию пользователей после импорта информации пользователей и статей, выберите эту опцию';
    $lang->about_importer = "Вы можете импортировать данные Zeroboard4, Zeroboard5 Beta или других программ в ZeroboardXE.\nЧтобы импортировать, Вам следует использовать <a href=\"#\" onclick=\"winopen('');return false;\">XML Экспортер (XML Exporter)</a>, чтобы конвертировать нужные данные в XML Файл и затем загрузить его.";

    $lang->about_target_path = "Чтобы получить вложения с Zeroboard4, пожалуйста, введите адрес, где установлена  Zeroboard4.\nЕсли она раположена на том же сервере, введите путь к Zeroboard4 как /home/USERID/public_html/bbs\nЕсли нет, введите адрес, где Zeroboard4 установлена. Например: http://Domain/bbs";
?>
